% Authors: Caroline Chaux, Laurent Duval
% Date : 2009/12/10
%
% The following set of functions implements the "nonlinear Stein-based estimator for multichannel image denoising"
% based on the following works, namely: 
% a) dual-tree M-band wavelet transform from Reference TIP2006
% b) neighborhood choice from Reference TIT2007
% c) non-linear Stein estimator from Reference TSP2008
% 
% Reference works:
% Title: Image analysis using a dual-tree M-band wavelet transform
% Author(s): CHAUX, C; DUVAL, L; PESQUET, JC
% Source: IEEE TRANSACTIONS ON IMAGE PROCESSING Volume: 15 Issue: 8 Pages: 2397-2412 Published: AUG 2006
% DOI: 10.1109/TIP.2006.875178 
% 
% Title: Noise covariance properties in dual-tree wavelet decompositions
% Author(s): CHAUX, C; PESQUET, JC; DUVAL, L
% Source: IEEE TRANSACTIONS ON INFORMATION THEORY Volume: 53 Issue: 12 Pages: 4680-4700 Published: DEC 2007
% DOI: 10.1109/TIT.2007.909104 
% 
% Title: A nonlinear Stein-based estimator for multichannel image denoising
% Author(s): CHAUX, C; DUVAL, L; BENAZZA-BENYAHIA, A; PESQUET, JC; 
% Source: IEEE TRANSACTIONS ON SIGNAL PROCESSING Volume: 56 Issue: 8 Pages: 3855-3870 Published: AUG 2008
% DOI: 10.1109/TSP.2008.921757 

clear all
% Set path variables
path1 = genpath('TOOLBOX_Den_Multi_light_v1.1/');
path2 = genpath('TOOLBOX_DTMband_solo/');
addpath(path1,path2);

% Define target SNR
psnr_ciblef = 20; % Single target SNR
% psnr_ciblef=20:2:30; % List of different SNRs

% Load tree channel data
data=double(imread('lenna_color_128x128.jpg'));

% Launch denoising for five noise realizations
MAIN_genSP_multi_indep

% Save PSNR results in a latex table in texmultitotcorrel.m
% Save individual denoised results in files 'SNR_channel_mean DTT...'
% Example: load('SNR_channel_mean DTT...');imagesc(xr{1});colormap gray


